@@ -1,6 +1,6 @@
 /*
     Profile
-    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 2002-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,11 @@
 #include "common.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
 #define PROFILE_DATA_TYPE_UNKNOW 0
 #define PROFILE_DATA_TYPE_SPACE 1
 #define PROFILE_DATA_TYPE_COMMENT 2
@@ -42,14 +47,15 @@ typedef struct ProfileList_Tag {
 typedef struct Profile_Tag {
 	gboolean edit;
 	gchar *file;
-	ProfileList *list;
+	ProfileList *list, *sublist;
 } Profile;
 
 
 /*	ե򳫤
 	file,ե̾
 	 RET,ץե														*/
-Profile *profile_open(const gchar *file);
+Profile *
+profile_open (const gchar *file);
 
 
 /*	եĤ
@@ -67,17 +73,34 @@ gchar *profile_get_string(Profile *profile,
 										const gchar *section,const gchar *key);
 
 
-/*	ե뤫ͤ
-	profile,ץե
-	section,
-	    key,
-	  value,ͤХåե
-	   size,ͤХåեΥ
-	   type,
-	    RET,TRUE:ｪλ,FALSE:顼										*/
-gboolean profile_get_value(Profile *profile,
-							const gchar *section,const gchar *key,
-							gpointer value,const gint size,const guint type);
+/*  ja:ե뤫ͤΥ
+    profile,ץե
+    section,
+        key,
+       type,
+        RET,Хȿ,0:顼                                               */
+gint
+profile_get_size (Profile     *profile,
+                  const gchar *section,
+                  const gchar *key,
+                  const guint  type);
+
+
+/*  ja:ե뤫ͤ
+    profile,ץե
+    section,
+        key,
+      value,ͤХåե
+       size,ͤХåեΥ
+       type,
+        RET,TRUE:ｪλ,FALSE:顼                                      */
+gboolean
+profile_get_value (Profile     *profile,
+                   const gchar *section,
+                   const gchar *key,
+                   gpointer     value,
+                   const gint   size,
+                   const guint  type);
 
 
 /*	եͤꤹ
@@ -90,7 +113,7 @@ gboolean profile_get_value(Profile *profile,
 	    RET,TRUE:ｪλ,FALSE:顼										*/
 gboolean profile_set_value(Profile *profile,
 					const gchar *section,const gchar *key,
-					const gpointer value,const gint size,const guint type);
+					gconstpointer value,const gint size,const guint type);
 
 
 /*	եΥ
@@ -109,4 +132,22 @@ gboolean profile_delete_key(Profile *profile,
 										const gchar *section,const gchar *key);
 
 
+/*	եΥ󤹤
+	profile,ץե
+	    RET,Υꥹ,NULL:顼									*/
+GList *
+profile_enum_section (Profile *profile);
+
+
+/*	եΥ󤹤
+	profile,ץե
+	section,
+	    RET,Υꥹ,NULL:顼									*/
+GList *
+profile_enum_key (Profile *profile, const gchar *section);
+
+
+#ifdef __cplusplus
+}
+#endif
 #endif
