@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -272,8 +272,8 @@ charlist_dialog_clicked_new (GtkWidget *widget, GtkTreeSelection *select)
     glist = gtk_container_children (GTK_CONTAINER (GTK_COMBO (combo)->list));
     for (i = g_list_length (glist) - 1; i >= 0; i--)
       {
-        label = gtk_label_get_text (GTK_LABEL
-                                (GTK_BIN (g_list_nth_data (glist, i))->child));
+        label = gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                                    (GTK_BIN (g_list_nth_data (glist, i)))));
         if (g_strcasecmp (label, charset) == 0)
             gtk_list_clear_items (GTK_LIST (GTK_COMBO (combo)->list),
                                                                     i, i + 1);
@@ -309,8 +309,8 @@ charlist_dialog_clicked_remove (GtkWidget *widget, GtkTreeSelection *select)
                                     (GTK_CONTAINER (GTK_COMBO (combo)->list));
             for (i = g_list_length (glist) - 1; i >= 0; i--)
               {
-                label = gtk_label_get_text (GTK_LABEL
-                                (GTK_BIN (g_list_nth_data (glist, i))->child));
+                label = gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                                    (GTK_BIN (g_list_nth_data (glist, i)))));
                 if (g_strcasecmp (label, charset) <= 0)
                     break;
               }
@@ -552,7 +552,7 @@ charlist_dialog (gchar *charlist)
     g_list_free (glist);
     /* ボタン */
     button0 = gtk_button_new_with_mnemonic (_("_New"));
-    button1 = gtk_button_new_with_mnemonic (_("_Remove"));
+    button1 = gtk_button_new_with_mnemonic (_("De_lete"));
     button2 = gtk_button_new_with_mnemonic (_("_Up"));
     button3 = gtk_button_new_with_mnemonic (_("_Down"));
     button4 = gtk_button_new_with_label (_("OK"));
@@ -585,7 +585,7 @@ charlist_dialog (gchar *charlist)
     gtk_container_add (GTK_CONTAINER (dialog), vbox);
 
     /* 表示 */
-    gtk_widget_set_sensitive (button0, FALSE);
+    charlist_dialog_changed_combo (GTK_COMBO (combo)->entry, NULL);
     gtk_widget_set_sensitive (button1, FALSE);
     gtk_widget_set_sensitive (button2, FALSE);
     gtk_widget_set_sensitive (button3, FALSE);
