@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -150,6 +150,7 @@ void command_open(gpointer callback_data,guint callback_action,
     g_object_set_data (G_OBJECT (dialog), "user_data", &file);
     if (open_path!=NULL)
         gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),open_path);
+    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (dialog));
     gtk_widget_show(dialog);
     gtk_grab_add(dialog);
     gtk_main();
@@ -164,30 +165,38 @@ void command_open(gpointer callback_data,guint callback_action,
 }
 
 
-void command_save(gpointer callback_data,guint callback_action,
-                                                            GtkWidget *widget)
+void
+command_save (gpointer   callback_data,
+              guint      callback_action,
+              GtkWidget *widget)
 {
-    gchar *text;
-    TmaidWindow *tmaid;
+  TmaidWindow *tmaid;
 
-    tmaid = g_object_get_data (G_OBJECT
+  tmaid = g_object_get_data (G_OBJECT
                 (gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
                     gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
                                                                 "user_data");
-    if (tmaid->create) {
-        command_saveas(callback_data,callback_action,widget);
-    } else {
-        text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
-                                                                tmaid->file);
-        if ((!tmaid->ft.overwrite || !fileio_isfile (tmaid->file)
+  if (tmaid->create)
+    {
+      command_saveas (callback_data, callback_action, widget);
+    }
+  else
+    {
+      gchar *text, *utf8str;
+
+      utf8str = g_filename_to_utf8 (tmaid->file, -1, NULL, NULL, NULL);
+      text = g_strdup_printf (_("%s\nThis file is existed.\n\nOver write?"),
+                                                                    utf8str);
+      g_free (utf8str);
+      if ((!tmaid->ft.overwrite || !fileio_isfile (tmaid->file)
                                     || misc_message_box ("Text maid",text, 1,
                                             _("_Yes"), _("_No"), NULL) == 0)
                                         && file_save_text (tmaid->file, tmaid))
-          {
-            tmaid_change_edit (tmaid, FALSE);
-            if (delete_list(&tmaid->undo)+delete_list(&tmaid->redo)>0)
-                set_menu_bar(tmaid);
-          }
+        {
+          tmaid_change_edit (tmaid, FALSE);
+          if (delete_list (&tmaid->undo) + delete_list (&tmaid->redo) > 0)
+            set_menu_bar (tmaid);
+        }
     }
 }
 
@@ -277,20 +286,23 @@ void command_saveas(gpointer callback_data,guint callback_action,
     g_object_set_data (G_OBJECT (dialog), "user_data", &file);
     if (save_path!=NULL)
         gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),save_path);
+    gtk_file_selection_hide_fileop_buttons (GTK_FILE_SELECTION (dialog));
     gtk_widget_show(dialog);
     gtk_grab_add(dialog);
     gtk_main();
 #endif /* not G_OS_WIN32 */
     if (file!=NULL) {
-        gchar *text, *label;
+        gchar *text, *label, *utf8str;
         GtkWidget *child;
         TmaidWindow *tmaid;
 
         child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
                     gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)));
         tmaid = g_object_get_data (G_OBJECT (child), "user_data");
+        utf8str = g_filename_to_utf8 (file, -1, NULL, NULL, NULL);
         text=g_strdup_printf(_("%s\nThis file is existed.\n\nOver write?"),
-                                                                        file);
+                                                                    utf8str);
+        g_free (utf8str);
         if ((!tmaid->ft.overwrite || !fileio_isfile (file)
                                     || misc_message_box ("Text maid", text, 1,
                                             _("_Yes"), _("_No"), NULL) == 0)
@@ -306,8 +318,8 @@ void command_saveas(gpointer callback_data,guint callback_action,
             gtk_label_set_text(GTK_LABEL(tmaid->label),label);
             g_free(label);
             /* ウインドウメニュー */
-            gtk_label_set_text(GTK_LABEL(GTK_BIN(tmaid->menu_item)->child),
-                                                                        file);
+            gtk_label_set_text (GTK_LABEL (gtk_bin_get_child
+                                        (GTK_BIN (tmaid->menu_item))), file);
             /* 諸設定 */
             tmaid->create = FALSE;
             tmaid_change_edit (tmaid, FALSE);
