@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -210,6 +210,7 @@ void format_dialog(void)
     /* リストボックス */
     store = gtk_list_store_new (1, G_TYPE_STRING);
     tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+    gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tview), FALSE);
     renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes
                         (_("Registered File Type"), renderer, "text", 0, NULL);
@@ -229,7 +230,7 @@ void format_dialog(void)
                                         GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
     /* ボタン */
     button0 = gtk_button_new_with_mnemonic (_("_New"));
-    button1 = gtk_button_new_with_mnemonic (_("_Remove"));
+    button1 = gtk_button_new_with_mnemonic (_("De_lete"));
     button2 = gtk_button_new_with_mnemonic (_("_Up"));
     button3 = gtk_button_new_with_mnemonic (_("_Down"));
     button4 = gtk_button_new_with_mnemonic (_("_Edit"));
