@@ -138,7 +138,7 @@ void set_menu_bar(TmaidWindow *tmaid)
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
                                 "<main>/File/Save As..."), TRUE);
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Reload"), !tmaid->create);
+                                "<main>/File/Reload..."), !tmaid->create);
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
                                 "<main>/File/Print..."), TRUE);
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
@@ -185,7 +185,7 @@ void set_menu_bar(TmaidWindow *tmaid)
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
                                 "<main>/File/Save As..."), FALSE);
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
-                                "<main>/File/Reload"), FALSE);
+                                "<main>/File/Reload..."), FALSE);
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
                                 "<main>/File/Print..."), FALSE);
         gtk_widget_set_sensitive (gtk_item_factory_get_widget (ifactory_menu,
@@ -530,9 +530,11 @@ prompt_close (TmaidWindow *tmaid)
 {
   if (tmaid->edit)
     {
-      gchar *text;
+      gchar *text, *utf8str;
 
-      text = g_strdup_printf (_("File %s was edited.\nSave?"), tmaid->file);
+      utf8str = g_filename_to_utf8 (tmaid->file, -1, NULL, NULL, NULL);
+      text = g_strdup_printf (_("File %s was edited.\nSave?"), utf8str);
+      g_free (utf8str);
       switch (misc_message_box ("Text maid", text, 0,
                                     _("_Yes"), _("_No"), _("Cancel"), NULL))
         {
