@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -377,10 +377,10 @@ static void property_dialog_clicked_ftype(GtkWidget *widget,gpointer user_data)
                                                     ? radio5 : radio6), TRUE);
             if (ftype[pos].crlf < 3)
                 gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo0)->entry),
-                        gtk_label_get_text (GTK_LABEL (GTK_BIN (g_list_nth_data
-                        (gtk_container_get_children
+                    gtk_label_get_text (GTK_LABEL (gtk_bin_get_child (GTK_BIN
+                    (g_list_nth_data (gtk_container_get_children
                         (GTK_CONTAINER (GTK_COMBO (combo0)->list)),
-                                                ftype[pos].crlf))->child)));
+                                                ftype[pos].crlf))))));
             gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin0),
                                                         ftype[pos].margin);
             gtk_spin_button_set_value(GTK_SPIN_BUTTON(spin1),ftype[pos].tab);
@@ -450,8 +450,8 @@ static void property_dialog_clicked_ok(GtkWidget *widget,FileType *ft)
         glist = gtk_container_children
                                     (GTK_CONTAINER (GTK_COMBO (combo0)->list));
         for (ft->crlf = g_list_length (glist) - 1; ft->crlf >= 0; ft->crlf--)
-            if (g_strcmp (gtk_label_get_text (GTK_LABEL (GTK_BIN
-                    (g_list_nth_data (glist, ft->crlf))->child)), text) == 0)
+            if (g_strcmp (gtk_label_get_text (GTK_LABEL (gtk_bin_get_child
+                (GTK_BIN (g_list_nth_data (glist, ft->crlf))))), text) == 0)
                 break;
         g_list_free (glist);
         if (ft->crlf < 0)
@@ -762,6 +762,7 @@ gboolean property_dialog(FileType *ft)
     store = gtk_list_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
     tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (tview), FALSE);
+    gtk_tree_view_set_enable_search (GTK_TREE_VIEW (tview), FALSE);
 
     renderer = gtk_cell_renderer_pixbuf_new ();
     column = gtk_tree_view_column_new_with_attributes
@@ -789,7 +790,7 @@ gboolean property_dialog(FileType *ft)
         gtk_list_store_append (store, &iter);
         gtk_list_store_set (store, &iter,
                         0, gdk_pixbuf_new_from_xpm_data ((const char **)xpm),
-                        1, gettext (color_name[i]), -1);
+                        1, _(color_name[i]), -1);
         g_free (xpm[1]);
       }
     /* スクロールウインドウ */
