@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Iwamoto,Kazuki http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,11 +23,17 @@
 #include "tmaid.h"
 
 
-typedef struct replace {
+#define REPLACE_CANCEL -1
+#define REPLACE_OK 1
+#define REPLACE_ALL 2
+#define REPLACE_NEXT 0
+
+
+typedef struct ReplaceString_Tag {
 	gboolean arrow;
 	gboolean ignorecase;
 	gchar *src,*dst;
-} REPLACE;
+} ReplaceString;
 
 
 extern gboolean replace_arrow;				/* ̐ݒ */
@@ -36,7 +42,7 @@ extern gchar *replace_text[32];				/* u镶 */
 extern gint replace_num;					/* o^Ău */
 
 
-gint replace_dialog(REPLACE *rp);
+gint replace_dialog(ReplaceString *rp);
 
 
 #endif
