@@ -18,7 +18,6 @@
 */
 #include <locale.h>
 #include "tmaid.h"
-#include "argument.h"
 #include "charlist.h"
 #include "command.h"
 #include "conf.h"
@@ -33,6 +32,7 @@
 #include "sigmain.h"
 #include "toolbar.h"
 #include "version.h"
+#include "misc/argument.h"
 #include "misc/fileio.h"
 #include "misc/license.h"
 #include "misc/profile.h"
@@ -54,7 +54,6 @@ gchar *arg_text=NULL;               /* プロセス間通信用変数 */
 gint def_width,def_height;          /* デフォルトのウインドウのサイズ */
 gint ftnum=0;                       /* ファイルタイプの数 */
 gint history=4;                     /* ファイルの履歴 */
-gint init_line=0;                   /* 初期のキャレット位置 */
 gint instance=-1;                   /* プロセス間通信用変数 */
 gint tcount=0;                      /* ファイルタイプのカウンタ */
 guint timer_id=0;                   /* タイマID */
@@ -142,18 +141,70 @@ DdemlCallback (UINT uType, UINT uFmt, HCONV hConv, HSZ hszTopic, HSZ hszServ,
                   {
                     gboolean *arg_files;
                     gchar **argv;
-                    gint i;
                     TmaidWindow *tmaid;
+                    gint i, array[2], def[2];
+                    ArgumentBool arg_n, arg_x;
+                    ArgumentValue arg_h, arg_l;
+                    ArgumentArray arg_s;
+                    ArgumentList arg_opts[] = {
+{"history", 'h',  "NUM",          N_("History"),        ARGUMENT_TYPE_VALUE, &arg_h},
+{"line",    'l',  "NUM",          N_("Caret Position"), ARGUMENT_TYPE_VALUE, &arg_l},
+{"new",     'n',  "ON/OFF",       N_("New File"),       ARGUMENT_TYPE_BOOL,  &arg_n},
+{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"),    ARGUMENT_TYPE_ARRAY, &arg_s},
+{"second",  'x',  "ON/OFF",       N_("Open Window"),    ARGUMENT_TYPE_BOOL,  &arg_x},
+{NULL,      '\0', NULL,           NULL,                 0,                   NULL}};
 
+                    /* ja:ファイルの履歴 */
+                    arg_h.val = history;
+                    arg_h.def = 4;
+                    /* ja:初期のキャレット位置 */
+                    arg_l.val = 0;
+                    arg_l.def = 0;
+                    /* ja:新規ファイル */
+                    arg_n.flag = newfile;
+                    arg_n.def = FALSE;
+                    /* ja:ウインドウサイズ */
+                    array[0] = def_width;
+                    array[1] = def_height;
+                    def[0] = gdk_screen_width ()  * 2 / 3;
+                    def[1] = gdk_screen_height () * 2 / 3;
+                    arg_s.leng = 2;
+                    arg_s.array = array;
+                    arg_s.def = def;
+                    /* ja:新規ウインドウ */
+                    arg_x.flag = second;
+                    arg_x.def = FALSE;
+                    /* ja:コマンドラインの解析 */
                     argv = g_strsplit (text, "\n", G_MAXINT);
-                    init_line = 0;
-                    arg_files = arg_analyse (argv, FALSE);
-                    for (i = 1; argv[i] != NULL; i++)
+                    arg_files = arg_analyse (argv, arg_opts);
+                    if (history != arg_h.val
+                                        && 0 <= arg_h.val && arg_h.val <= 10)
+                      {
+                        /* ja:履歴の整理 */
+                        GList *glist;
+                        GtkWidget *menu_shell;
+
+                        history = arg_h.val;
+                        menu_shell = gtk_item_factory_get_widget
+                                                (ifactory_menu, "<main>/File");
+                        glist = gtk_container_children
+                                                (GTK_CONTAINER (menu_shell));
+                        for (i = g_list_length (glist) - 3;
+                            i > history - (history == 0) + MENUFILE - 2; i--)
+                          gtk_container_remove (GTK_CONTAINER
+                                    (menu_shell), g_list_nth_data (glist, i));
+                        g_list_free (glist);
+                      }
+                    newfile = arg_n.flag;
+                    def_width = array[0];
+                    def_height = array[1];
+                    second = arg_x.flag;
+                    for (i = 1; argv[i]; i++)
                         if (arg_files[i])
                           {
                             tmaid = file_open_edit (argv[i]);
-                            if (init_line != 0) /* 指定行に移動 */
-                                jump_operation (tmaid, init_line);
+                            if (arg_l.val != 0) /* 指定行に移動 */
+                              jump_operation (tmaid, arg_l.val);
                           }
                     g_free (arg_files);
                     g_strfreev (argv);
@@ -170,9 +221,11 @@ DdemlCallback (UINT uType, UINT uFmt, HCONV hConv, HSZ hszTopic, HSZ hszServ,
 #endif
 
 
-static gchar *menu_translate(const gchar *path,gpointer func_data)
+static gchar *
+menu_translate (const gchar *path,
+                gpointer     func_data)
 {
-   return gettext(path);
+ return (gchar *)_(path);
 }
 
 
@@ -181,7 +234,7 @@ int main(int argc,char *argv[])
     gboolean *arg_files, license = FALSE;
     gchar *arg, *section, *key, *tmp, *utf8str;
     const gchar *charset;
-    gint i, count=0, leng, length=0;
+    gint i, count=0, leng, length=0, init_line = 0;
     Profile *profile;
     TmaidWindow *tmaid;
     GdkBitmap *mask;
@@ -197,7 +250,7 @@ int main(int argc,char *argv[])
 {N_("/File/_Close"),                 "<control>W", command_close,   0,"<Item>"},
 {N_("/File/_Save"),                  "<control>S", command_save,    0,"<Item>"},
 {N_("/File/Save _As..."),            NULL,         command_saveas,  0,"<Item>"},
-{N_("/File/_Reload"),                "<control>R", command_reload,  0,"<Item>"},
+{N_("/File/_Reload..."),             "<control>R", command_reload,  0,"<Item>"},
 {N_("/File/Sep1"),                   NULL,         NULL,            0,"<Separator>"},
 {N_("/File/_Print..."),              "<control>P", command_print,   0,"<Item>"},
 {N_("/File/Sep2"),                   NULL,         NULL,            0,"<Separator>"},
@@ -256,11 +309,7 @@ int main(int argc,char *argv[])
         path = fileio_get_full_path (argv[0]);
         dirname = g_path_get_dirname (path);
         g_free (path);
-# ifdef G_OS_WIN32
-        locale = g_strconcat (dirname, "\\locale", NULL);
-# else /* not G_OS_WIN32 */
-        locale = g_strconcat (dirname, "/locale", NULL);
-# endif /* not G_OS_WIN32 */
+        locale = g_strconcat (dirname, G_DIR_SEPARATOR_S, "locale", NULL);
         g_free (dirname);
         bindtextdomain (PACKAGE, locale);
         g_free (locale);
@@ -564,7 +613,60 @@ int main(int argc,char *argv[])
         gtk_exit (0);
 
     /* コマンドラインの解析 */
-    arg_files=arg_analyse(argv,TRUE);
+    {
+      gint array[2], def[2];
+      ArgumentBool arg_n, arg_x;
+      ArgumentValue arg_h, arg_l;
+      ArgumentArray arg_s;
+      ArgumentExit arg_v;
+      ArgumentHelp arg_q;
+      ArgumentList arg_opts[] = {
+{"history", 'h',  "NUM",          N_("History"),        ARGUMENT_TYPE_VALUE, &arg_h},
+{"line",    'l',  "NUM",          N_("Caret Position"), ARGUMENT_TYPE_VALUE, &arg_l},
+{"new",     'n',  "ON/OFF",       N_("New File"),       ARGUMENT_TYPE_BOOL,  &arg_n},
+{"size",    's',  "WIDTH,HEIGHT", N_("Window Size"),    ARGUMENT_TYPE_ARRAY, &arg_s},
+{"second",  'x',  "ON/OFF",       N_("Open Window"),    ARGUMENT_TYPE_BOOL,  &arg_x},
+{"version", 'v',  NULL,           N_("About"),          ARGUMENT_TYPE_EXIT,  &arg_v},
+{"help",    '?',  NULL,           N_("Help"),           ARGUMENT_TYPE_HELP,  &arg_q},
+{NULL,      '\0', NULL,           NULL,                 0,                   NULL}};
+
+    /* ja:ファイルの履歴 */
+    arg_h.val = history;
+    arg_h.def = 4;
+    /* ja:初期のキャレット位置 */
+    arg_l.val = init_line;
+    arg_l.def = 0;
+    /* ja:新規ファイル */
+    arg_n.flag = newfile;
+    arg_n.def = FALSE;
+    /* ja:ウインドウサイズ */
+    array[0] = def_width;
+    array[1] = def_height;
+    def[0] = gdk_screen_width ()  * 2 / 3;
+    def[1] = gdk_screen_height () * 2 / 3;
+    arg_s.leng = 2;
+    arg_s.array = array;
+    arg_s.def = def;
+    /* ja:新規ウインドウ */
+    arg_x.flag = second;
+    arg_x.def = FALSE;
+    /* ja:バージョン */
+    arg_v.str =
+TMAID_VERSION_NOTICE"\n"
+TMAID_COPYRIGHT_NOTICE"\n"
+"This is free software; see the source for copying conditions.  There is NO\n"
+"warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n";
+    /* ja:ヘルプ */
+    arg_q.str = TMAID_COPYRIGHT_NOTICE"\n\n";
+    arg_files = arg_analyse (argv, arg_opts);
+    if (0 <= arg_h.val && arg_h.val <= 10)
+      history = arg_h.val;
+    if (arg_l.val >= 0)
+      init_line = arg_l.val;
+    def_width = array[0];
+    def_height = array[1];
+    second = arg_x.flag;
+  }
 
     /* ファイルタイプ */
     if (ftnum<=0) {
@@ -673,9 +775,9 @@ int main(int argc,char *argv[])
     /* ステータスバー */
     status=gtk_statusbar_new();
     /* カーソル座標 */
-    label_cursor = gtk_label_new (NULL);
+    label_cursor = gtk_label_new ("");
     gtk_label_set_justify (GTK_LABEL (label_cursor), GTK_JUSTIFY_CENTER);
-    frame = gtk_frame_new(NULL);
+    frame = gtk_frame_new (NULL);
     gtk_container_add( GTK_CONTAINER (frame), label_cursor);
     /* テキスト */
     label = gtk_label_new ("");
@@ -937,8 +1039,7 @@ int main(int argc,char *argv[])
         }
         while (i<10) {
             key=g_strdup_printf("history%d",i++);
-            profile_set_value(profile,"tmaid",key,(gpointer)"",sizeof(gchar),
-                                                    PROFILE_VALUE_TYPE_STRING);
+            profile_delete_key (profile, "tmaid", key);
             g_free(key);
         }
         /* 検索 */
