@@ -53,6 +53,8 @@ const static gchar *authors =
 "\n"
 "Translate :\n"
 "\n"
+"Packager :\n"
+"    yasuo-s\n"
 "Special Thanks :\n"
 "    Takuro Ashie\n"
 "    Koji SHIMIZU(21)\n"
